<?php
// $Id: luceneapi_facet.admin.inc,v 1.1.2.7 2009/07/31 00:09:18 cpliakas Exp $

/**
 * @file
 * Administrative settings for Search Lucene Facets.
 *
 * @ingroup luceneapi
 */

/**
 * Administrative settings for Search Lucene Facets.
 *
 * @param &$form_state
 *   A keyed array containing the current state of the form.
 * @param $module
 *   A string containing the Search Lucene API module.
 * @return
 *   A FAPI array passed through system_settings_form().
 */
function luceneapi_facet_admin_settings_form(&$form_state, $module) {
  $form = array('realm' => array(), 'weight' => array());

  // gets facets available to the module, stored in facet data container
  $type = luceneapi_index_type_get($module);
  $facets = luceneapi_facet_facets_get($module, $type);
  $form['facet_data'] = array('#type' => 'value', '#value' => $facets);

  // stores the module so we can sort the facets in the theme function
  $form['module'] = array('#type' => 'value', '#value' => $module);

  // iterates over realms, builds form for individual sections
  foreach (luceneapi_facet_realms_get() as $realm_name => $realm) {

    if (!empty($facets)) {

      // gets facets, formats options array
      $options = array();
      foreach ($facets as $facet_name => $facet) {
        $options[$facet_name] = '';
      }

      // index settings fieldset
      $form['facets'][$realm_name] = array(
        '#type' => 'fieldset',
        '#title' => sprintf('%s: %s', t('Realm'), t($realm['title'])),
        '#collapsible' => TRUE,
      );

      // adds description of relam if one was provided
      if (isset($realm['description'])) {
        $form['facets'][$realm_name]['#description'] = t($realm['description']);
      }

      // adds facet checkboxes
      $variable = sprintf('luceneapi_facet:%s:%s', $module, $realm_name);
      $form['facets'][$realm_name]['table'][$variable] = array(
        '#type' => 'checkboxes',
        '#options' => $options,
        '#default_value' => variable_get($variable, array()),
      );

      // adds facet weight dropboxes
      foreach ($options as $facet_name => $title) {
        $variable = sprintf('luceneapi_facet:%s:%s:%s:weight', $module, $realm_name, $facet_name);
        $form['weight'][$realm_name][$variable] = array(
          '#type' => 'weight',
          '#title' => '',
          '#delta' => 50,
          '#default_value' => variable_get($variable, 0),
          '#attributes' => array('class' => 'luceneapi-facet-weight'),
        );
      }

    }
    else {
      $form['facets'] = array(
        '#value' => t('No facets are available to this module.'),
      );
      return $form;
    }
  }

  // finalizes the form and returns
  $form = system_settings_form($form);
  $form['#theme'] = 'luceneapi_facet_admin_settings_form';
  return $form;
}

/**
 * Themes the facet form into a draggable table.
 *
 * @param $form
 *   A FAPI array containing a fieldset.
 * @return
 *   A themed form element.
 */
function theme_luceneapi_facet_admin_settings_form($form) {
  $output = '';
  $module = $form['module']['#value'];

  // initializes table headers
  $headers = array();
  $headers[] = array('data' => t('Enabled'), 'class' => 'checkbox');
  $headers[] = t('Facet');
  $headers[] = t('Weight');
  $headers[] = t('Description');

  // if there are facets defined for this module, adds them
  foreach (element_children($form['facets']) as $realm) {
    $rows = array();

    // makes the realm's facet table draggable
    $table_id = sprintf('luceneapi-facet-table-%s', $realm);
    drupal_add_tabledrag($table_id, 'order', 'sibling', 'luceneapi-facet-weight');

    // adds elements corresponding with a facet as a draggable row
    foreach (element_children($form['facets'][$realm]['table']) as $variable) {

      // adds the facets weights and sorts
      $facets = $form['facet_data']['#value'];
      foreach ($facets as $facet_name => $facet) {
        $weight_var = sprintf('luceneapi_facet:%s:%s:%s:weight', $module, $realm, $facet_name);
        $facets[$facet_name]['weight'] = variable_get($weight_var, 0);
      }
      uasort($facets, 'luceneapi_facet_sort');

      // iterates over sorted facets
      foreach ($facets as $facet_name => $facet) {
        $weight_var = sprintf('luceneapi_facet:%s:%s:%s:weight', $module, $realm, $facet_name);
        $rows[] = array(
          'class' => 'draggable',
          'data' => array(
            array(
              'data' => drupal_render($form['facets'][$realm]['table'][$variable][$facet_name]),
              'class' => 'checkbox'
            ),
            array(
              'data' => $facet['title']
            ),
            array(
              'data' => drupal_render($form['weight'][$realm][$weight_var]),
              'class' => 'dropbox'
            ),
            array(
              'data' => isset($facet['description']) ? $facet['description'] : '',
            ),
          ),
        );
      }

    }

    // formats the table for the facets, the table will have dragable rows
    $form['facets'][$realm]['table']['#value'] .= theme(
      'table', $headers, $rows, array('id' => $table_id)
    );
  }

  $output .= drupal_render($form);
  return $output;
}
