<?php
// $Id: luceneapi.error.inc,v 1.3.2.2 2009/07/02 19:38:15 cpliakas Exp $

/**
 * @file
 * Functions relating to error handling.  This file should be called only when
 * processing application level errors in order to cut down on the amount of
 * unused code loaded by Search Lucene API.
 *
 * @ingroup luceneapi
 */

/**
 * Helper function for luceneapi_throw_error().
 *
 * @param $err
 *   A string or an Exception class containing the error message.
 * @param $variables
 *   An array of variables to replace in the message on display, NULL if message
 *   is already translated or not possible to translate.  The parameter is
 *   meaningless if $err is an Exception object.
 * @param $type
 *   A string containing the type parameter passed to watchdog(), defaults to
 *   luceneapi.
 * @return
 *   NULL
 */
function _luceneapi_throw_error($err, $variables, $type) {
  global $user, $_luceneapi_is_error;
  $_luceneapi_is_error = TRUE;

  // gets message from $err, determines if Exception should be translated
  if ($err instanceof Exception) {
    $variables = NULL;
    if ($err instanceof LuceneAPI_Exception) {
      $message = $err->getMessage();
    }
    else {
      $message = t($err->getMessage());
    }
    $message .= ' '. t(
      'Error thrown in %file on line %line.',
      array(
        '%file' => $err->getFile(),
        '%line' => $err->getLine(),
      )
    );
  }
  else {
    $message = (string)$err;
  }

  // logs message, converts $message to translated string if not already
  watchdog((string)$type, $message, $variables, WATCHDOG_ERROR);
  if (is_array($variables)) {
    $message = t($message, $variables);
  }

  // gets error dependent on permissions
  if (user_access('view luceneapi errors', $user)) {
    $params = array($message, 'error');
  }
  else {
    $params = array(t(luceneapi_setting_get('error_message')), 'error');
  }

  // passes params to drupal_set_message()
  if (!empty($params[0])) {
    call_user_func_array('drupal_set_message', $params);
  }
}

/**
 * Returns error as to why the index path could not be retrieved from a module.
 * This function assumes that the module is not in the array returned by the
 * luceneapi_module_list() function.
 *
 * @param $module
 *   A string containing the module.
 * @return
 *   A translated string containing the error message.
 */
function _luceneapi_hook_error_get($module) {
  if (!module_exists($module)) {
    $errstr = t(
      'Module %module is either not installed or not enabled.',
      array('%module' => $module)
    );
  }
  elseif (!module_hook($module, 'luceneapi_index')) {
    $errstr = t(
      'Module %module does not implement %hook.',
      array(
        '%module' => $module,
        '%hook' => 'hook_luceneapi_index()',
      )
    );
  }
  else {
    $errstr = t(
      'Path not returned by %hook in module %module.',
      array(
        '%hook' => "hook_luceneapi_index('path')",
        '%module' => $module,
      )
    );
  }
  return $errstr;
}
