<?php
// $Id: luceneapi.hooks.inc,v 1.3.2.7 2009/07/23 02:27:54 cpliakas Exp $

/**
 * @file
 * Example file that defines the Search Lucene API hooks.
 *
 * @ingroup luceneapi
 */

/**
 * Defined by modules that maintain a Lucene index.  Modules that implement
 * hook_luceneapi_index() usually implement hooks hook_search() and
 * hook_update_index() as well.
 *
 * @param $op
 *   A string containing the operation being performed.
 * @return
 *   Varies dependent on $op:
 *    - path: A string containing the filesystem path to the Lucene index.
 *    - type: A string containing the type of content being indexed, i.e. "node".
 * @see hook_search()
 * @see hook_update_index()
 */
function hook_luceneapi_index($op) {
}

/**
 * Allows modules to alter the search query object. This hook is invoked after
 * the facet callbacks are invoked and before the search is executed.  The
 * query passed to this hook is a container of both the form query and facet
 * queries.
 *
 * @param $query
 *   A Zend_Search_Lucene_Search_Query_Boolean object modeling the search query.
 * @param $module
 *   A string containing the module handling the search.
 * @param $type
 *   A string containing the type of content $module indexes, NULL if no type.
 * @return
 *   NULL
 */
function hook_luceneapi_query_alter($query, $module, $type = NULL) {
}

/**
 * Passes the positive keys found during the search, useful for adding
 * additional logging or analysis of Lucene searches.
 *
 * @param $positive_keys
 *   An array of positive keys found during the search.
 * @param $module
 *   A string containing the module handling the search.
 * @param $type
 *   A string contaning the type of content indexed by $module.
 * @return
 *   NULL
 */
function hook_luceneapi_positive_keys($positive_keys, $module, $type = NULL) {
}

/**
 * Provides access to the search result array so it may be altered before it is
 * passed to the theme layer.
 *
 * @param &$result
 *   An array containing a search result item.
 * @param $module
 *   A string containing the module handling the search.
 * @param $type
 *   A string contaning the type of content indexed by $module.
 * @return
 *   NULL
 */
function hook_luceneapi_result_alter(&$result, $module, $type = NULL) {
}

/**
 * Allows for altering of the document object before it is added to the index.
 * Invoking this hook allows developers to add additional fields, for example
 * CCK data, to the index.
 *
 * @param $doc
 *   A Zend_Search_Lucene_Document object being added to the index.
 * @param $item
 *   A mixed value modeling the content being added to the index, usually a
 *   Drupal node object.
 * @param $module
 *   A string containing the module managing the Lucene index.
 * @param $type
 *   A string contaning the type of content indexed by $module.
 * @return
 *   NULL
 */
function hook_luceneapi_document_alter($doc, $item, $module, $type = NULL) {
}

/**
 * This hook is invoked just before a document is removed from the index.
 * It allows modules to filter which results may be deleted.  For example,
 * adding a subquery that searches for nodes of the content type "page" will
 * delete only those nodes.  This hook useful in multisite environment where
 * all sites can add documents to an index but can remove only their own
 * content.
 *
 * @param $item
 *   A mixed value modeling the content being removed from the index, usually a
 *   Drupal node object.
 * @param $module
 *   A string containing the module managing the Lucene index.
 * @param $type
 *   A string contaning the type of content indexed by $module.
 * @return
 *   A Zend_Search_Lucene_Search_Query object.
 */
function hook_luceneapi_document_delete($item, $module, $type = NULL) {
}

/**
 * Defines analyzers.  Refer to the Zend Framework documentation on how to
 * create custom analyzers.
 *
 * @return
 *   An associative array keyed by the class name of the analyzer to the display
 *   name.
 */
function hook_luceneapi_analyzer() {
}

/**
 * Used by Search Lucene API modules to define which Lucene fields are sortable.
 *
 * @param $module
 *   A string containing the module to which the fields apply.
 * @param $type
 *   A string contaning the type of content indexed by $module.
 * @return
 *   An associative array of Lucene fields keyed by the Lucene field to the
 *   display name of the field.
 */
function hook_luceneapi_sortable_fields($module, $type = NULL) {
}

/**
 * Allows modules to alter the sort links.
 *
 * @param &$sort
 *   The sort array passed to luceneapi_find().
 * @param $module
 *   A string containing the module handling the search.
 * @param $type
 *   A string contaning the type of content indexed by $module.
 * @param $type
 *   A string contaning the type of content indexed by $module.
 */
function hook_luceneapi_sort_arguments_alter(&$sort, $module, $type = NULL) {
}
